# CSV to netCDF Converter  

This python script accepts a directory containing one or more CSV files and it creates a CF-compliant netCDF 4 file. 

There are two versions of the script; one is a simple version that takes all the values in all CSV files and appends them to a single netCDF file, whilst the other is a more complex version that involves averaging the values for each indicator for the previous 10 minutes and then creates one netCDF file per month of data. It doesn't matter how the CSV files are named; set the ```sourcefolder``` variable and all files within this folder will be processed, but there are example data files in the ```source_data``` folder to get you started

These scripts were produced to handle data generated by some meteorological instruments and the format they write the timestamp for each reading is a little odd, so you will almost certainly have to amend this to match the format of your own data.   

## Setup

For both options you will need to set a few variables. Around line 8, set the latitude, longitude, altitude of the station, and the data source and out put directories.
```
station_lat   = 50.317993
station_lon   = -4.189128
station_altitude = 8

sourcefolder = 'source_data'
targetfolder = 'output/'
outputfilenameprefix = 'Penlee_Met_simple'
```

In both versions you will also need to specify the global attribute values; these start on line 81 in the simple version and line 155 in the 10 minute average version. 
```
# set the global attributes
rootgrp.id = 'PML-Penlee-Met'
rootgrp.naming_authority = 'Plymouth Marine Laboratory'
rootgrp.Metadata_Conventions = 'Unidata Dataset Discovery v1.0'
rootgrp.Conventions = 'CF-1.6'
rootgrp.featureType = 'timeSeries'
# publisher details
rootgrp.publisher_name = 'Plymouth Marine Laboratory'
rootgrp.publisher_phone = '+44 (0)1752 633100'
rootgrp.publisher_url = 'http://www.westernchannelobservatory.org.uk/penlee'
rootgrp.publisher_email = 'forinfo@pml.ac.uk'
rootgrp.title = 'Penlee observatory meteorological data'
rootgrp.summary = 'Air temperature measurements taken at Penlee Point observatory; measurements are taken every 4 seconds.'
# creator details
rootgrp.creator_name = 'Ben Calton'
rootgrp.creator_email = 'bac@pml.ac.uk'
rootgrp.creator_url = 'https://rsg.pml.ac.uk/'
```

## Simple Version

This loads all of the data in ```source_data``` into a single netCDF file. There is just one variable, air temperature.

## 10 Minute Average Version

This loads the all of the data in ```source_data``` into a series of netCDF files, each file containing 1 months worth of data with the year and month forming part of the filename (note: the example data only spans one month so only one file will be produced). There are multiple indicators, and the indicator values are stored in the netCDF file as an average for the previous 10 minutes.

## Running the script

To execute the script run the following:
```
python /path/to/the/repository/CSV-to-netCDF/csv-to-netcdf-simple.py
```
or
```
python /path/to/the/repository/CSV-to-netCDF/csv-to-netcdf-10min-avg.py
```

In both cases any files that cannot be processed will be reported with the filename, and any row within a single file that cannot be processed will also be reported